summaryrefslogtreecommitdiff
path: root/dvbapi.h
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2000-09-10 10:51:58 +0200
committerKlaus Schmidinger <vdr@tvdr.de>2000-09-10 10:51:58 +0200
commita334a2df334ccd3c2a2756b374b675a15bdb3de8 (patch)
tree54f3208ff1d55f2f6dc01ff0afc3ffd68a10dde5 /dvbapi.h
parentc00d4ea326e61d76d7ab5760a5c06646d6b88ab0 (diff)
downloadvdr-a334a2df334ccd3c2a2756b374b675a15bdb3de8.tar.gz
vdr-a334a2df334ccd3c2a2756b374b675a15bdb3de8.tar.bz2
Added a 'Setup' menu
Diffstat (limited to 'dvbapi.h')
-rw-r--r--dvbapi.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/dvbapi.h b/dvbapi.h
index 9f954302..a43e7075 100644
--- a/dvbapi.h
+++ b/dvbapi.h
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: dvbapi.h 1.13 2000/09/03 09:25:53 kls Exp $
+ * $Id: dvbapi.h 1.14 2000/09/10 10:03:29 kls Exp $
*/
#ifndef __DVBAPI_H
@@ -53,9 +53,13 @@ private:
static cDvbApi *dvbApi[MAXDVBAPI];
public:
static cDvbApi *PrimaryDvbApi;
+ static bool SetPrimaryDvbApi(int n);
+ // Sets the primary DVB device to 'n' (which must be in the range
+ // 1...NumDvbApis) and returns true if this was possible.
static cDvbApi *GetDvbApi(int Ca = 0);
// Selects a free DVB device, starting with the highest device number.
// If Ca is nor 0, the device with the given number will be returned
// if it is not currently recording.
int Index(void);
// Returns the index of this DvbApi.
@@ -53,9 +53,13 @@ private:
static cDvbApi *GetDvbApi(int Ca = 0);
- // Selects a free DVB device, starting with the highest device number.
- // If Ca is nor 0, the device with the given number will be returned
+ // Selects a free DVB device, starting with the highest device number
+ // (but avoiding, if possible, the PrimaryDvbApi).
+ // If Ca is not 0, the device with the given number will be returned
// if it is not currently recording.
int Index(void);